# coding: utf-8

"""
    EVM API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 2.1
    Generated by: https://openapi-generator.tech
"""

from openapi_evm_api.paths.token0_address_token1_address_pair_address.get import GetPairAddress
from openapi_evm_api.paths.pair_address_reserves.get import GetPairReserves


class DefiApi(
    GetPairAddress,
    GetPairReserves,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
