# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

import unittest

import openapi_streams
from openapi_streams.model.addresses_types_addresses_response import AddressesTypesAddressesResponse
from openapi_streams import configuration


class TestAddressesTypesAddressesResponse(unittest.TestCase):
    """AddressesTypesAddressesResponse unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()
