# coding: utf-8

"""
    Solana API

    Moralis Solana API  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

import unittest

import openapi_sol_api
from openapi_sol_api.model.nft_metadata import NFTMetadata
from openapi_sol_api import configuration


class TestNFTMetadata(unittest.TestCase):
    """NFTMetadata unit test stubs"""
    _configuration = configuration.Configuration()


if __name__ == '__main__':
    unittest.main()
