# coding: utf-8

# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from openapi_evm_api.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from openapi_evm_api.model.block import Block
from openapi_evm_api.model.block_date import BlockDate
from openapi_evm_api.model.block_transaction import BlockTransaction
from openapi_evm_api.model.chain_list import ChainList
from openapi_evm_api.model.endpoint_weights import EndpointWeights
from openapi_evm_api.model.ens import Ens
from openapi_evm_api.model.erc20_allowance import Erc20Allowance
from openapi_evm_api.model.erc20_metadata import Erc20Metadata
from openapi_evm_api.model.erc20_price import Erc20Price
from openapi_evm_api.model.erc20_token_balance import Erc20TokenBalance
from openapi_evm_api.model.erc20_transaction import Erc20Transaction
from openapi_evm_api.model.erc20_transaction_collection import Erc20TransactionCollection
from openapi_evm_api.model.erc721_metadata import Erc721Metadata
from openapi_evm_api.model.get_multiple_nfts_dto import GetMultipleNftsDto
from openapi_evm_api.model.historical_nft_transfer import HistoricalNftTransfer
from openapi_evm_api.model.ipfs_file import IpfsFile
from openapi_evm_api.model.ipfs_file_request import IpfsFileRequest
from openapi_evm_api.model.log import Log
from openapi_evm_api.model.log_collection import LogCollection
from openapi_evm_api.model.log_event import LogEvent
from openapi_evm_api.model.log_event_by_address import LogEventByAddress
from openapi_evm_api.model.metadata_resync import MetadataResync
from openapi_evm_api.model.native_balance import NativeBalance
from openapi_evm_api.model.native_erc20_price import NativeErc20Price
from openapi_evm_api.model.nft import Nft
from openapi_evm_api.model.nft_collection import NftCollection
from openapi_evm_api.model.nft_collections import NftCollections
from openapi_evm_api.model.nft_contract_metadata import NftContractMetadata
from openapi_evm_api.model.nft_contract_metadata_collection import NftContractMetadataCollection
from openapi_evm_api.model.nft_metadata import NftMetadata
from openapi_evm_api.model.nft_metadata_collection import NftMetadataCollection
from openapi_evm_api.model.nft_owner import NftOwner
from openapi_evm_api.model.nft_owner_collection import NftOwnerCollection
from openapi_evm_api.model.nft_transfer import NftTransfer
from openapi_evm_api.model.nft_transfer_collection import NftTransferCollection
from openapi_evm_api.model.nft_wallet_collections import NftWalletCollections
from openapi_evm_api.model.normalized_metadata import NormalizedMetadata
from openapi_evm_api.model.normalized_metadata_attribute import NormalizedMetadataAttribute
from openapi_evm_api.model.reserves_collection import ReservesCollection
from openapi_evm_api.model.reserves_pair import ReservesPair
from openapi_evm_api.model.resolve import Resolve
from openapi_evm_api.model.run_contract_dto import RunContractDto
from openapi_evm_api.model.token_item import TokenItem
from openapi_evm_api.model.trade import Trade
from openapi_evm_api.model.trade_collection import TradeCollection
from openapi_evm_api.model.transaction import Transaction
from openapi_evm_api.model.transaction_collection import TransactionCollection
from openapi_evm_api.model.transaction_collection_verbose import TransactionCollectionVerbose
from openapi_evm_api.model.web3version import Web3version
