# coding: utf-8

"""
    Streams Api

    API that provides access to Moralis Streams  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from openapi_streams import schemas  # noqa: F401


class UsageStatsStreams(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "totalWebhooksDelivered",
            "totalTxsProcessed",
            "streamId",
            "totalLogsProcessed",
            "totalWebhooksFailed",
            "totalTxsInternalProcessed",
        }
        
        class properties:
            totalWebhooksDelivered = schemas.Float64Schema
            totalWebhooksFailed = schemas.Float64Schema
            totalLogsProcessed = schemas.Float64Schema
            totalTxsProcessed = schemas.Float64Schema
            totalTxsInternalProcessed = schemas.Float64Schema
            streamId = schemas.StrSchema
            __annotations__ = {
                "totalWebhooksDelivered": totalWebhooksDelivered,
                "totalWebhooksFailed": totalWebhooksFailed,
                "totalLogsProcessed": totalLogsProcessed,
                "totalTxsProcessed": totalTxsProcessed,
                "totalTxsInternalProcessed": totalTxsInternalProcessed,
                "streamId": streamId,
            }
        additional_properties = schemas.NotAnyTypeSchema
    
    totalWebhooksDelivered: MetaOapg.properties.totalWebhooksDelivered
    totalTxsProcessed: MetaOapg.properties.totalTxsProcessed
    streamId: MetaOapg.properties.streamId
    totalLogsProcessed: MetaOapg.properties.totalLogsProcessed
    totalWebhooksFailed: MetaOapg.properties.totalWebhooksFailed
    totalTxsInternalProcessed: MetaOapg.properties.totalTxsInternalProcessed
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["totalWebhooksDelivered"]) -> MetaOapg.properties.totalWebhooksDelivered: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["totalTxsProcessed"]) -> MetaOapg.properties.totalTxsProcessed: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["streamId"]) -> MetaOapg.properties.streamId: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["totalLogsProcessed"]) -> MetaOapg.properties.totalLogsProcessed: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["totalWebhooksFailed"]) -> MetaOapg.properties.totalWebhooksFailed: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["totalTxsInternalProcessed"]) -> MetaOapg.properties.totalTxsInternalProcessed: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["totalWebhooksDelivered"], typing_extensions.Literal["totalTxsProcessed"], typing_extensions.Literal["streamId"], typing_extensions.Literal["totalLogsProcessed"], typing_extensions.Literal["totalWebhooksFailed"], typing_extensions.Literal["totalTxsInternalProcessed"], ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["totalWebhooksDelivered"]) -> MetaOapg.properties.totalWebhooksDelivered: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["totalTxsProcessed"]) -> MetaOapg.properties.totalTxsProcessed: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["streamId"]) -> MetaOapg.properties.streamId: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["totalLogsProcessed"]) -> MetaOapg.properties.totalLogsProcessed: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["totalWebhooksFailed"]) -> MetaOapg.properties.totalWebhooksFailed: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["totalTxsInternalProcessed"]) -> MetaOapg.properties.totalTxsInternalProcessed: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["totalWebhooksDelivered"], typing_extensions.Literal["totalTxsProcessed"], typing_extensions.Literal["streamId"], typing_extensions.Literal["totalLogsProcessed"], typing_extensions.Literal["totalWebhooksFailed"], typing_extensions.Literal["totalTxsInternalProcessed"], ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        totalWebhooksDelivered: typing.Union[MetaOapg.properties.totalWebhooksDelivered, decimal.Decimal, int, float, ],
        totalTxsProcessed: typing.Union[MetaOapg.properties.totalTxsProcessed, decimal.Decimal, int, float, ],
        streamId: typing.Union[MetaOapg.properties.streamId, str, ],
        totalLogsProcessed: typing.Union[MetaOapg.properties.totalLogsProcessed, decimal.Decimal, int, float, ],
        totalWebhooksFailed: typing.Union[MetaOapg.properties.totalWebhooksFailed, decimal.Decimal, int, float, ],
        totalTxsInternalProcessed: typing.Union[MetaOapg.properties.totalTxsInternalProcessed, decimal.Decimal, int, float, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'UsageStatsStreams':
        return super().__new__(
            cls,
            *_args,
            totalWebhooksDelivered=totalWebhooksDelivered,
            totalTxsProcessed=totalTxsProcessed,
            streamId=streamId,
            totalLogsProcessed=totalLogsProcessed,
            totalWebhooksFailed=totalWebhooksFailed,
            totalTxsInternalProcessed=totalTxsInternalProcessed,
            _configuration=_configuration,
        )
