# coding: utf-8

# flake8: noqa

"""
    Auth API

    API that provides authentication services for dapps.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

__version__ = "1.0.0"

# import ApiClient
from openapi_auth.api_client import ApiClient

# import Configuration
from openapi_auth.configuration import Configuration

# import exceptions
from openapi_auth.exceptions import OpenApiException
from openapi_auth.exceptions import ApiAttributeError
from openapi_auth.exceptions import ApiTypeError
from openapi_auth.exceptions import ApiValueError
from openapi_auth.exceptions import ApiKeyError
from openapi_auth.exceptions import ApiException
